import json
import asyncio
from fastapi import APIRouter, Depends
from fastapi.encoders import jsonable_encoder
from sqlalchemy.orm import Session
from starlette.responses import StreamingResponse
from app.models import JobStatus, Jobs as JobModel
from app.dependencies import get_db

router = APIRouter()


async def job_event_generator(db: Session):
    while True:
        jobs = db.query(JobModel).filter(JobModel.status == JobStatus.TODO).all()
        if jobs:
            job_payload = jsonable_encoder(jobs)
            yield f"data: {json.dumps(job_payload)}\n\n"
        await asyncio.sleep(5)


# A reasonable heartbeat/refresh


@router.get("/jobs/stream")
async def stream_jobs(db: Session = Depends(get_db)):
    return StreamingResponse(job_event_generator(db), media_type="text/event-stream")
